@@ -180,6 +180,10 @@ class Customer(object):
                         'code': '204',
                         'message': 'produit non fupé'
                         }
+        url = core.database_url(**FUPDB_CREDENTIALS)
+        with records.Database(url) as db:
+            sql = "DELETE FROM customer WHERE name=:name"
+            db.query(sql, name=self.name)
         return result
 
     def get_cdr_from_aiguillier(self, last_date):
